@@ -1,5 +1,9 @@
-__version__ = '1.0.0'
-nickname = 'Afternoon Review'
+__version__ = '1.1.0'
+nickname = 'Business Hugs'
+last_version = __version__
+  # This is used by `(pragma :hy …)` to guess whether an unreleased
+  # version of Hy is new enough. In a released version, it's simply
+  # equal to `__version__`.
 
 
 def _initialize_env_var(env_var, default_val):
